#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-compat
version:              0.14.1
visibility:           public
id:                   base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
key:                  base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
license:              MIT
copyright:
    (c) 2012-2018 Simon Hengel,
    (c) 2014-2018 João Cristóvão,
    (c) 2015-2018 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

synopsis:             A compatibility layer for base
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.  See the
    <https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown README>
    for what is covered. Also see the
    <https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown changelog>
    for recent changes.

    Note that @base-compat@ does not add any orphan instances.
    There is a separate package,
    @<http://hackage.haskell.org/package/base-orphans base-orphans>@,
    for that.

    In addition, @base-compat@ does not backport any data types
    or type classes. See
    @<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#data-types-and-type-classes this section of the README>@
    for more info.

    @base-compat@ is designed to have zero dependencies. For a
    version of @base-compat@ that depends on compatibility
    libraries for a wider support window, see the
    @<http://hackage.haskell.org/package/base-compat-batteries base-compat-batteries>@
    package. Most of the modules in this library have the same
    names as in @base-compat-batteries@ to make it easier to
    switch between the two. There also exist versions of each
    module with the suffix @.Repl@, which are distinct from
    anything in @base-compat-batteries@, to allow for easier
    use in GHCi.

category:             Compatibility
abi:                  b12a69721b7418cc2bbe5876bcaaa98c
exposed:              True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.Compat.Repl
    Control.Concurrent.MVar.Compat Control.Concurrent.MVar.Compat.Repl
    Control.Exception.Compat Control.Exception.Compat.Repl
    Control.Monad.Compat Control.Monad.Compat.Repl
    Control.Monad.Fail.Compat Control.Monad.Fail.Compat.Repl
    Control.Monad.IO.Class.Compat Control.Monad.IO.Class.Compat.Repl
    Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Lazy.Unsafe.Compat.Repl
    Control.Monad.ST.Unsafe.Compat Control.Monad.ST.Unsafe.Compat.Repl
    Data.Bifoldable.Compat Data.Bifoldable.Compat.Repl
    Data.Bifoldable1.Compat Data.Bifoldable1.Compat.Repl
    Data.Bifunctor.Compat Data.Bifunctor.Compat.Repl
    Data.Bitraversable.Compat Data.Bitraversable.Compat.Repl
    Data.Bits.Compat Data.Bits.Compat.Repl Data.Bool.Compat
    Data.Bool.Compat.Repl Data.Complex.Compat Data.Complex.Compat.Repl
    Data.Either.Compat Data.Either.Compat.Repl Data.Foldable.Compat
    Data.Foldable.Compat.Repl Data.Foldable1.Compat
    Data.Foldable1.Compat.Repl Data.Function.Compat
    Data.Function.Compat.Repl Data.Functor.Compat
    Data.Functor.Compat.Repl Data.Functor.Compose.Compat
    Data.Functor.Compose.Compat.Repl Data.Functor.Const.Compat
    Data.Functor.Const.Compat.Repl Data.Functor.Contravariant.Compat
    Data.Functor.Contravariant.Compat.Repl Data.Functor.Identity.Compat
    Data.Functor.Identity.Compat.Repl Data.Functor.Product.Compat
    Data.Functor.Product.Compat.Repl Data.Functor.Sum.Compat
    Data.Functor.Sum.Compat.Repl Data.IORef.Compat
    Data.IORef.Compat.Repl Data.List.Compat Data.List.Compat.Repl
    Data.List.NonEmpty.Compat Data.List.NonEmpty.Compat.Repl
    Data.Monoid.Compat Data.Monoid.Compat.Repl Data.Proxy.Compat
    Data.Proxy.Compat.Repl Data.Ratio.Compat Data.Ratio.Compat.Repl
    Data.STRef.Compat Data.STRef.Compat.Repl Data.Semigroup.Compat
    Data.Semigroup.Compat.Repl Data.String.Compat
    Data.String.Compat.Repl Data.Traversable.Compat
    Data.Traversable.Compat.Repl Data.Tuple.Compat
    Data.Tuple.Compat.Repl Data.Type.Coercion.Compat
    Data.Type.Coercion.Compat.Repl Data.Type.Equality.Compat
    Data.Type.Equality.Compat.Repl Data.Typeable.Compat
    Data.Typeable.Compat.Repl Data.Version.Compat
    Data.Version.Compat.Repl Data.Void.Compat Data.Void.Compat.Repl
    Data.Word.Compat Data.Word.Compat.Repl Debug.Trace.Compat
    Debug.Trace.Compat.Repl Foreign.Compat Foreign.Compat.Repl
    Foreign.ForeignPtr.Compat Foreign.ForeignPtr.Compat.Repl
    Foreign.ForeignPtr.Safe.Compat Foreign.ForeignPtr.Safe.Compat.Repl
    Foreign.ForeignPtr.Unsafe.Compat
    Foreign.ForeignPtr.Unsafe.Compat.Repl Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Alloc.Compat.Repl Foreign.Marshal.Array.Compat
    Foreign.Marshal.Array.Compat.Repl Foreign.Marshal.Compat
    Foreign.Marshal.Compat.Repl Foreign.Marshal.Safe.Compat
    Foreign.Marshal.Safe.Compat.Repl Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Unsafe.Compat.Repl Foreign.Marshal.Utils.Compat
    Foreign.Marshal.Utils.Compat.Repl Numeric.Compat
    Numeric.Compat.Repl Numeric.Natural.Compat
    Numeric.Natural.Compat.Repl Prelude.Compat Prelude.Compat.Repl
    System.Environment.Compat System.Environment.Compat.Repl
    System.Exit.Compat System.Exit.Compat.Repl System.IO.Compat
    System.IO.Compat.Repl System.IO.Error.Compat
    System.IO.Error.Compat.Repl System.IO.Unsafe.Compat
    System.IO.Unsafe.Compat.Repl Text.Read.Compat Text.Read.Compat.Repl
    Text.Read.Lex.Compat Text.Read.Lex.Compat.Repl
    Type.Reflection.Compat Type.Reflection.Compat.Repl

import-dirs:          /usr/lib/ghc-9.6.6/site-local/base-compat-0.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/base-compat-0.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/base-compat-0.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-compat
hs-libraries:         HSbase-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
depends:              base-4.18.2.1 ghc-prim-0.10.0 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-base-compat/html/base-compat.haddock
haddock-html:         /usr/share/doc/haskell-base-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

